/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code (www.playsophy.com).
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * ***** END LICENSE BLOCK ***** */

/**********************************************************************************
 * mozileTBSave.js V0.52: this file implements save/post option in Mozile. It uses
 * "save" settings in the mozile configuration file to decide what transport driver
 * to use to save a file.
 *
 * James A. Overton: File altered 2003-11-19 to suit the MozileXPI, and renamed to mozileTBSave.js
 *
 * POST05:
 * - be more robust ie/ if garbage in configuration etc
 * - "save elements" option: make this save all changed editable elements. This means
 * tracking changes in this file.
 * - allow user to set global default for saving (right now, fixed to "save to file") in config file
 * - pass file name/id and actual content back in any errors (change mozDataTransport)
 *
 **********************************************************************************/

/**
 * Configuration: this will move into an XML file that configures mozile for a page/web site
 *
 * Options:
 * hostname | method to use | element or whole document.
 * ex/ for host "www.playsophy.com", could have "webdav false" or "http true" or "file false"
 * 
 * Note:
 * in general, only save the editable area that has changed as the rest of a file may be just
 * template information, fixed by a CMS. Only saving an editable area would correspond to posting
 * a blog entry in a blog.
 */


function mozileSave()
{
	// much simplified by the code in mozileConfiguration.js

	var method = mozileTarget.document.MOZILE_RSD_CONFIG["method"];
	if(!method || method=="") {
		method="alert"; // default to poping up an alert box with raw XHTML
	}

	var editonly = mozileTarget.document.MOZILE_RSD_CONFIG["editonly"];
	if(!editonly || editonly=="") {
		editonly="false";
	}

	// get contents to save and an identifier for that content
	var contentToSave;
	var id = document.location.pathname;
	//create a new XMLSerializer
	var objXMLSerializer = new XMLSerializer;
	if(editonly=="true")
	{
		// get the contents of the editable area
		var cssr = mozileSelection.getEditableRange();
		var editableArea = cssr.top;
		var dataToSaveRange = mozileTarget.document.createRange();
		dataToSaveRange.selectNodeContents(editableArea);
		var dataToSave = dataToSaveRange.cloneContents();

		contentToSave = objXMLSerializer.serializeToString(dataToSave);

		if(editableArea.id) // append editable area id to file name if there is an id
			id = document.location.pathname + "#" + editableArea.id;
	}
	else {
		contentToSave = objXMLSerializer.serializeToString(mozileTarget.document);
	}

	var td = new mozTransportDriver(method);

	td.save(id, contentToSave, __mozileSaved);
}

/**
 * Callback from Transport - used if there is a problem.
 *
 * POST05: get more information back! 
 */ 
function __mozileSaved(reqObj) 
{	
	if (reqObj.isError)
		alert ("Couldn't save document \n" + reqObj.statusText);
}
